summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLuc Verhaegen <libv@skynet.be>2009-11-28 18:26:21 +0000
committerLuc Verhaegen <libv@skynet.be>2009-11-28 18:26:21 +0000
commit6c5d4cc608f3f661dd011a5dd871c0ac617ca77f (patch)
treee822162a939421a34fce14301b4aaea880833811
parent1265d8d3fbca6cb497f1824827c6c52dee93bc39 (diff)
downloadast2050-flashrom-6c5d4cc608f3f661dd011a5dd871c0ac617ca77f.zip
ast2050-flashrom-6c5d4cc608f3f661dd011a5dd871c0ac617ca77f.tar.gz
Boards: Add Asus P4B266LM (Sony Vaio PCV-RX650)
Corresponding to flashrom svn r788. Signed-off-by: Luc Verhaegen <libv@skynet.be> Acked-by: Allan Bjorklund <abjork@speakeasy.net>
-rw-r--r--board_enable.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/board_enable.c b/board_enable.c
index 46e09c7..e6d37c1 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -770,7 +770,9 @@ static int intel_ich_gpio19_raise(const char *name)
}
/**
* Suited for Asus P4P800-E Deluxe: Intel socket478 + 865PE + ICH5R.
*/
static int intel_ich_gpio21_raise(const char *name)
{
@@ -1156,6 +1158,7 @@ struct board_pciid_enable board_pciid_enables[] = {
{0x1106, 0x3189, 0x1043, 0x807F, 0x1106, 0x3177, 0x1043, 0x808C, NULL, NULL, "ASUS", "A7V8X", board_asus_a7v8x},
{0x1106, 0x3177, 0x1043, 0x80A1, 0x1106, 0x3205, 0x1043, 0x8118, NULL, NULL, "ASUS", "A7V8X-MX SE", board_asus_a7v8x_mx},
{0x8086, 0x1a30, 0x1043, 0x8070, 0x8086, 0x244b, 0x1043, 0x8028, NULL, NULL, "ASUS", "P4B266", intel_ich_gpio22_raise},
+ {0x8086, 0x1A30, 0x1043, 0x8025, 0x8086, 0x244B, 0x104D, 0x80F0, NULL, NULL, "ASUS", "P4B266-LM", intel_ich_gpio21_raise},
{0x8086, 0x2570, 0x1043, 0x80F2, 0x105A, 0x3373, 0x1043, 0x80F5, NULL, NULL, "ASUS", "P4P800-E Deluxe", intel_ich_gpio21_raise},
{0x10B9, 0x1541, 0, 0, 0x10B9, 0x1533, 0, 0, "asus", "p5a", "ASUS", "P5A", board_asus_p5a},
{0x10DE, 0x0030, 0x1043, 0x818a, 0x8086, 0x100E, 0x1043, 0x80EE, NULL, NULL, "ASUS", "P5ND2-SLI Deluxe", board_asus_p5nd2_sli},
@@ -770,7 +770,9 @@ static int intel_ich_gpio19_raise(const char *name)
}
/**
- * Suited for Asus P4P800-E Deluxe: Intel socket478 + 865PE + ICH5R.
+ * Suited for:
+ * - Asus P4B266LM (Sony Vaio PCV-RX650): socket478 + 845D + ICH2.
+ * - Asus P4P800-E Deluxe: Intel socket478 + 865PE + ICH5R.
*/
static int intel_ich_gpio21_raise(const char *name)
OpenPOWER on IntegriCloud